#!/bin/bash

# Pour installer en même temps le spool d'imprimante, au choix, passer l'un des arguments suivant :
# - liris : pour le LIRIS
# - mfae : pour le MFAE
# - konica : pour les copieurs de l'administration

PROGDIR=$(readlink -m "$(dirname "$0")")

# Sortir si échec
set -e

# Root
if test $(id -u) -ne 0 ; then
	echo "Need to be root"
	exit 2
fi

# Java
if command -v apt > /dev/null ; then
	dpkg -l | grep -q default-jre  || apt install default-jre
elif command -v dnf > /dev/null ; then
	rpm -qa | grep -q java-latest || INSTALL+=" java-latest-openjdk.x86_64"
	rpm -qa | grep -q dialog || INSTALL+=" dialog"
	if test -n "$INSTALL" ; then
		dnf install $INSTALL
	fi
else
	echo "OS non reconnu"
	exit 2
fi

# Program
if ! test -d /opt/papercut ; then
	mkdir /opt/papercut
fi
cp -rf ${PROGDIR}/* /opt/papercut/

# Launcher
if ! test -d /usr/local/share/applications/ ; then
	mkdir /usr/local/share/applications/
fi
cp -f ${PROGDIR}/biz-papercut-pcng-client-uit-UserClient.desktop /usr/local/share/applications/

# Autostart
read -p "Autostart ? (o/n) : " autostart
case $autostart in
	o|O|y|Y) cp /usr/local/share/applications/biz-papercut-pcng-client-uit-UserClient.desktop /etc/xdg/autostart/ ;;
	n|N) test -f /etc/xdg/autostart/biz-papercut-pcng-client-uit-UserClient.desktop && rm /etc/xdg/autostart/biz-papercut-pcng-client-uit-UserClient.desktop
esac

/opt/papercut/pc-client-linux.sh --silent &

# Auto install printer
if test -n "$1" ; then
	if test -f /usr/share/cups/model/KMbeuC35ux.ppd ; then
		case "$1" in
			konica|Konica|KONICA)
				lpadmin -p Copieurs_Administration -D "Papercut Konica" -E -L "Administration" -m KMbeuC35ux.ppd -v lpd://spoolkonica.ad.ec-lyon.fr/Copieurs_Konica
			;;
	# Quel driver ???
	#		ricoh|Ricoh|RICOH)
	#			lpadmin -p Copieurs_Administration -D "Papercut Ricoh" -E -L "Administration" -m ???? -v lpd://spoolkonica.ad.ec-lyon.fr/Copieurs_Ricoh
	#		;;
			liris|Liris|LIRIS)
				lpadmin -p Copieurs_LIRIS -D "Papercut Konica" -E -L "LIRIS" -m KMbeuC35ux.ppd -v lpd://spoolkonica.ad.ec-lyon.fr/Copieurs_Liris
			;;
			mfae|Mfae|MFAE)
				lpadmin -p Copieurs_MFAE -D "Papercut Konica" -E -L "MFAE" -m KMbeuC35ux.ppd -v lpd://spoolkonica.ad.ec-lyon.fr/Copieurs_Mfae
			;;
			*)
				echo "$1 non géré"
				exit 1
			;;
		esac
	else
		echo "Drivers Konica non installés"
		exit 2
	fi
fi
